Thursday, September 20, 2012
About snapmirror logging
About snapmirror logging:
a. how to check snapmirror log is enable
filerA> options snapmirror.log.enable
snapmirror.log.enable on
b. how to enable snapmirror logging
options snapmirror.log.enable on
c. where the output of snapmirror
/etc/log/snapmirror.0
Examples of log files
The following is an example of a log file from the source side:
log Fri Jul 27 20:00:01 GMT - - Start_Logging
cmd Fri Jul 27 20:00:20 GMT - - Snapmirror_on
src Fri Jul 27 20:41:09 GMT filer1:vol1 filer2:vol1 Request (10.56.17.133)
src Fri Jul 27 20:41:32 GMT filer1:vol1 filer2:vol1 Abort (Destination not allowed)
src Fri Jul 27 20:45:31 GMT filer1:vol0 filer1:vol1 Request (10.56.17.132)
src Fri Jul 27 20:45:35 GMT filer1:vol0 filer1:vol1 Start
src Fri Jul 27 20:51:40 GMT filer1:vol0 filer1:vol1 End (26200 KB)
src Fri Jul 27 22:41:09 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Request
(10.56.17.133)
src Fri Jul 27 22:41:12 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Start
src Fri Jul 27 22:41:13 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Abort (Non
unicode directory found in source qtree.)
src Fri Jul 27 22:45:53 GMT filer1:/vol/vol1/qtb filer2:/vol/vol1/qsmb Request
(10.56.17.133)
src Fri Jul 27 22:45:56 GMT filer1:/vol/vol1/qtb filer2:/vol/vol1/qsmb Start
src Fri Jul 27 22:45:59 GMT filer1:/vol/vol1/qtb filer2:/vol/vol1/qsmb End (3800 KB)
cmd Fri Jul 27 22:50:29 GMT filer1:/vol/vol1/qtb filer2:/vol/vol1/qsmb Release_command
The following is an example of a log file from the destination side.
dst Fri Jul 27 22:50:18 GMT filer1:vol0 filer1:vol1 Request (Initialization)
dst Fri Jul 27 22:50:20 GMT filer1:vol0 filer1:vol1 Abort (Destination is not
restricted)
dst Fri Jul 27 22:57:17 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Request
(Initialize)
dst Fri Jul 27 22:57:24 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Start
dst Fri Jul 27 22:57:36 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB End (55670 KB)
dst Fri Jul 27 23:10:03 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Request
(Scheduled)
dst Fri Jul 27 23:10:07 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Start
dst Fri Jul 27 23:10:18 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB End (12900 KB)
cmd Sat Jul 28 00:05:29 GMT - filer2:/vol/vol1/qtB Quiesce_start
cmd Sat Jul 28 00:05:29 GMT - filer2:/vol/vol1/qtB Quiesce_end
cmd Sat Jul 28 00:05:40 GMT - filer2:/vol/vol1/qtB Break_command
cmd Sat Jul 28 00:41:05 GMT filer1:/vol/vol1/qtA filer2:/vol/vol1/qtB Resync_command
log Sat Jul 28 00:41:10 GMT - - End_Logging
Sunday, May 15, 2011
Netapp Snapshot Management Cheat Sheet
Written by geekyS
This article explains the different commands related to Netapp Snapshot Management.
Creating a test volume of 10gb to perform snapshot related operations
geekyfacts-filer > vol create testvol aggr 10g
Creation of volume 'testvol' with size 10g on containing aggregate
geekyfacts-filer > df -h testvol
Filesystem total used avail capacity Mounted on
/vol/testvol/ 8192MB 1420KB 8190MB 0% /vol/testvol/
/vol/testvol/.snapshot 2048MB 0MB 2048MB 0% /vol/testvol/.snapshot
geekyfacts-filer >
Snapshot Create
geekyfacts-filer > snap list testvol
Volume testvol
working...
No snapshots exist.
geekyfacts-filer > snap create testvol testsnap
creating snapshot...
geekyfacts-filer > snap list testvol
Volume testvol
working...
%/used %/total date name
---------- ---------- ------------ --------
0% ( 0%) 0% ( 0%) Dec 19 01:02 testsnap
geekyfacts-filer >
Snapshot Rename
geekyfacts-filer > snap rename testvol testsnap snaptest
geekyfacts-filer > snap list testvol
Volume testvol
working...
%/used %/total date name
---------- ---------- ------------ --------
3% ( 3%) 0% ( 0%) Dec 19 01:02 snaptest
geekyfacts-filer >
Snapshot Delete
geekyfacts-filer > snap delete testvol snaptest
deleting snapshot...
geekyfacts-filer > snap list testvol
Volume testvol
working...
No snapshots exist.
geekyfacts-filer >
Snap Scheduling
Scheduling automatic snapshot to keep 2 weekly, 2 daily, 8 hourly(taken at hours 8,12,16,20) online.
geekyfacts-filer > snap sched testvol 2 2 8@8,12,16,20
geekyfacts-filer > snap sched testvol
Volume testvol: 2 2 8@8,12,16,20
geekyfacts-filer >
Snap Space Reservation
Default snapshot space reserve is 20% of the volume size
geekyfacts-filer > snap reserve testvol
Volume testvol: current snapshot reserve is 20% or 2097152 k-bytes.
geekyfacts-filer > df -h testvol
Filesystem total used avail capacity Mounted on
/vol/testvol/ 8192MB 1796KB 8190MB 0% /vol/testvol/
/vol/testvol/.snapshot 2048MB 0MB 2048MB 0% /vol/testvol/.snapshot
Changing the snapshot reserve to 5% of the volume size
geekyfacts-filer > snap reserve testvol 5
geekyfacts-filer > snap reserve testvol
Volume testvol: current snapshot reserve is 5% or 524288 k-bytes.
geekyfacts-filer > df -h testvol
Filesystem total used avail capacity Mounted on
/vol/testvol/ 9728MB 1796KB 9726MB 0% /vol/testvol/
/vol/testvol/.snapshot 512MB 0MB 512MB 0% /vol/testvol/.snapshot
geekyfacts-filer >
Snap Restore
Export and mount the testvol to put some contents in the volume.
geekyfacts-filer > exportfs -p rw=geekyfacts.com,root=geekyfacts.com /vol/testvol
Login to the server for which volume was exported(in our case geekyfacts.com)
[root@geekyfacts]# mkdir /test
[root@geekyfacts]# mount geekyfacts-filer:/vol/testvol /test
[root@geekyfacts]# df -h /test
Filesystem Size Used Avail Use% Mounted on
geekyfacts-filer:/vol/testvol
9.5G 1.8M 9.5G 1% /test
[root@geekyfacts]# cd /test
[root@geekyfacts]# touch file.before_snapshot
geekyfacts-filer > snap create testvol testsnap
creating snapshot...
geekyfacts-filer > snap list testvol
Volume testvol
working...
%/used %/total date name
---------- ---------- ------------ --------
0% ( 0%) 0% ( 0%) Dec 19 02:15 testsnap
[root@geekyfacts]# touch file.aftersnap
[root@geekyfacts]# ls -l
total 0
-rw-r--r-- 1 root root 0 Dec 19 02:16 file.aftersnap
-rw-r--r-- 1 root root 0 Dec 19 02:15 file.before_snapshot
Snapshot testsnap hold only file.before_snapshot
[root@geekyfacts]# ls .snapshot/testsnap/
file.before_snapshot
Volume restore using Snapshot
geekyfacts-filer > snap restore -t vol -s testsnap testvol
WARNING! This will revert the volume to a previous snapshot.
All modifications to the volume after the snapshot will be
irrevocably lost.
Volume testvol will be made restricted briefly before coming back online.
Are you sure you want to do this? yes
You have selected volume testvol, snapshot testsnap
Proceed with revert? yes
Volume testvol: revert successful.
[root@geekyfacts]# ls
file.before_snapshot
File Restore using Snapshot
[root@geekyfacts]# rm file.before_snapshot
rm: remove regular empty file `file.before_snapshot'? y
geekyfacts-filer> snap restore -t file -s testsnap -r /vol/testvol/file.before_snapshot /vol/testvol/file.before_snapshot
WARNING! This will restore a file from a snapshot into the active
filesystem. If the file already exists in the active filesystem,
it will be overwritten with the contents from the snapshot.
Are you sure you want to do this? yes
You have selected file /vol/testvol/file.before_snapshot, snapshot testsnap
It will be restored as /vol/testvol/file.before_snapshot
Proceed with restore? yes
[root@geekyfacts]# ls
file.before_snapshot
geekyfacts-file >#
Snap Delta
[root@geekyfacts]# touch file{1,2,3,4}
geekyfacts-file > snap create testvol testsnap1
creating snapshot...
geekyfacts-file > snap list testvol
Volume testvol
working...
%/used %/total date name
---------- ---------- ------------ --------
0% ( 0%) 0% ( 0%) Dec 19 02:23 testsnap1
19% (19%) 0% ( 0%) Dec 19 02:15 testsnap
geekyfacts-file > snap delta testvol
Volume testvol
working...
From Snapshot To KB changed Time Rate (KB/hour)
--------------- -------------------- ----------- ------------ ---------------
testsnap1 Active File System 56 20s 10080.000
testsnap testsnap1 424 0d 00:08 3173.388
Summary...
From Snapshot To KB changed Time Rate (KB/hour)
--------------- -------------------- ----------- ------------ ---------------
testsnap Active File System 480 0d 00:08 3449.101
geekyfacts-file>
Snap reclaimable
geekyfacts-file > snap reclaimable testvol testsnap
Processing (Press Ctrl-C to exit) .
snap reclaimable: Approximately 424 Kbytes would be freed.
Saturday, March 26, 2011
Thursday, January 20, 2011
Virtual Provisioning with Solutions Enabler
Virtual Provisioning with Solutions Enabler
source: http://www.emcstorageinfo.comData Devices are devices with datadev attribute. Only Data Devices can be part of Thin Pool. Devices with different protection scheme can be supported for use in Thin Pools. It is depending on specific Enginuity level. All devices with the datadev attribute are used for exclusively for populating Thin Pools.
Create command file (Thin.txt) with following syntax:
create dev count=10, config=2-Way-Mir, attribute=datadev, emulation=FBA, size=4602;
# symconfigure -sid 44 -file thin.txt commit –v –nop
A Configuration Change operation is in progress. Please wait...
Establishing a configuration change session...............Established.
Processing symmetrix 000190101244
{
create dev count=10, size=4602, emulation=FBA,
config=2-Way Mir, mvs_ssid=0000, attribute=datadev;
}
Performing Access checks..................................Allowed.
Checking Device Reservations..............................Allowed.
Submitting configuration changes..........................Submitted
…..
…..
…..
Step 125 of 173 steps.....................................Executing.
Step 130 of 173 steps.....................................Executing.
Local: COMMIT............................................Done.
Terminating the configuration change session..............Done.
The configuration change session has successfully completed.
# symdev list -sid 44 -datadev
Symmetrix ID: 000190101244
Device Name Directors Device
--------------------------- ------------- -------------------------------------
Sym Physical SA :P DA :IT Config Attribute Sts Cap(MB)
--------------------------- ------------- -------------------------------------
10C4 Not Visible ???:? 01A:C4 2-Way Mir N/A (DT) RW 4314
10C5 Not Visible ???:? 16C:D4 2-Way Mir N/A (DT) RW 4314
10C6 Not Visible ???:? 15B:D4 2-Way Mir N/A (DT) RW 4314
10C7 Not Visible ???:? 02D:C4 2-Way Mir N/A (DT) RW 4314
10C8 Not Visible ???:? 16A:D4 2-Way Mir N/A (DT) RW 4314
10C9 Not Visible ???:? 01C:C4 2-Way Mir N/A (DT) RW 4314
10CA Not Visible ???:? 16B:C4 2-Way Mir N/A (DT) RW 4314
Thin Pool can be created using symconfigure command and without adding data devices:
# symconfigure -sid 44 -cmd "create pool Storage type=thin;" commit –nop
Once pool is created, data devices can be added to the pool and enabled
Thursday, January 13, 2011
List all the external locks held in the box & how to release
# symcfg -sid 15 list -lockn all
Symmetrix ID: 000192601234
S Y M M E T R I X L O C K S
Lock Lock Lock Time SymmID Attachment Status Number Usage Held (Sec)
000192601234 Local Locked 15 Config Change 9311
To Release the lock 15 held on array 1234 .
symcfg -sid 1234 -lockn 15 release -force
Thursday, December 30, 2010
How to revert setting device attributes
set device SymDevName[:SymDevName]
[emulation=EmulationType]
[attribute=[NO] device_attr];
i.e
set dev 0D44 attribute= NO SCSI3_PERSIST_RESERV;
Wednesday, December 15, 2010
Netapp Snapshot: quick guide
Netapp Snapshot technology helps in creating point-in-time copies of file systems, which you can use to protect data—from a single file to a complete disaster recovery solution. You can create a Snapshot copies in less than a second, regardless of volume size or level of activity on your NetApp system. Currently there is a limit of 255 snapshots per volume. Read more at Netapp Tech library.
Here is a quick overview of the netapp snapshot management commands.
To list a snapshots on a netapp storage volume
filer2> snap list vol79
Volume vol79
working...
%/used %/total date name
---------- ---------- ------------ --------
0% ( 0%) 0% ( 0%) Nov 12 22:00 hourly.0
0% ( 0%) 0% ( 0%) Nov 12 21:00 hourly.1
0% ( 0%) 0% ( 0%) Nov 12 00:00 nightly.0
0% ( 0%) 0% ( 0%) Nov 11 00:00 nightly.1
0% ( 0%) 0% ( 0%) Nov 10 00:00 weekly.0
0% ( 0%) 0% ( 0%) Nov 09 00:00 nightly.2
0% ( 0%) 0% ( 0%) Nov 08 00:00 nightly.3
0% ( 0%) 0% ( 0%) Nov 07 00:00 nightly.4
0% ( 0%) 0% ( 0%) Nov 03 00:00 weekly.1
filer2>
To create a manual snapshot
filer2> snap create vol79 test123
filer2> snap list vol79
Volume vol79
working...
%/used %/total date name
---------- ---------- ------------ --------
0% ( 0%) 0% ( 0%) Nov 12 22:09 test123
0% ( 0%) 0% ( 0%) Nov 12 22:00 hourly.0
0% ( 0%) 0% ( 0%) Nov 12 21:00 hourly.1
0% ( 0%) 0% ( 0%) Nov 12 00:00 nightly.0
0% ( 0%) 0% ( 0%) Nov 11 00:00 nightly.1
0% ( 0%) 0% ( 0%) Nov 10 00:00 weekly.0
0% ( 0%) 0% ( 0%) Nov 09 00:00 nightly.2
0% ( 0%) 0% ( 0%) Nov 08 00:00 nightly.3
0% ( 0%) 0% ( 0%) Nov 07 00:00 nightly.4
0% ( 0%) 0% ( 0%) Nov 03 00:00 weekly.1
filer2>
Print the snapshot schedules for a volume (hourly, nightly, weekly snapshot)
filer2> snap sched vol79
Volume vol79: 2 5 2
filer2>
Change snapshot schedules
filer2> snap sched vol79 2 4 3
filer2> snap sched vol79
Volume vol79: 2 4 3
filer2>
Show snapshot reserve space ( the space allotted to store snapshot in volume )
filer2> snap reserve vol79
Volume vol79: current snapshot reserve is 0% or 0 k-bytes.
filer2> df -h vol79
Filesystem total used avail capacity Mounted on
/vol/vol79/ 300GB 229GB 70GB 77% /vol/vol79/
/vol/vol79/.snapshot 0MB 65MB 0MB ---% /vol/vol79/.snapshot
Change snaphot reserve space
filer2> snap reserve vol79 5
filer2> df -h vol79
Filesystem total used avail capacity Mounted on
/vol/vol79/ 285GB 229GB 55GB 81% /vol/vol79/
/vol/vol79/.snapshot 15GB 66MB 14GB 0% /vol/vol79/.snapshot
filer2>
To delete a snapshot
filer2> snap delete vol79 test123
filer2>
Saturday, November 13, 2010
How to verify FA port connections
Symmetrix ID: 000290xxxxx67
S Y M M E T R I X D I R E C T O R P O R T S
Director Port Status Connection Status
Ident Type Status P0 P1 P2 P3 P0 P1 P2 P3
FA-3A FibreChannel Online ON ON N/A N/A X X - -
FA-4A FibreChannel Online ON ON N/A N/A X X - -
FA-7A FibreChannel Online ON ON N/A N/A X X - -
FA-8A FibreChannel Online ON ON N/A N/A - X - -
FA-9A FibreChannel Online ON ON N/A N/A X X - -
FA-10A FibreChannel Online ON ON N/A N/A X X - -
FA-13A FibreChannel Online ON ON N/A N/A X X - -
FA-14A FibreChannel Online ON ON N/A N/A X X - -
FA-3B FibreChannel Online ON ON N/A N/A X - - -
FA-4B FibreChannel Online ON ON N/A N/A X - - -
FA-7B FibreChannel Online ON ON N/A N/A X - - -
FA-8B FibreChannel Online ON ON N/A N/A X - - -
FA-9B FibreChannel Online ON ON N/A N/A X - - -
FA-10B FibreChannel Online ON ON N/A N/A X - - -
FA-13B FibreChannel Online ON ON N/A N/A X - - -
FA-14B FibreChannel Online ON ON N/A N/A X - - -
FA-3C FibreChannel Online ON ON N/A N/A X - - -
FA-4C FibreChannel Online ON ON N/A N/A X - - -
FA-7C FibreChannel Online ON ON N/A N/A X - - -
FA-8C FibreChannel Online ON ON N/A N/A X - - -
FA-9C FibreChannel Online ON ON N/A N/A X - - -
FA-10C FibreChannel Online ON ON N/A N/A X - - -
FA-13C FibreChannel Online ON ON N/A N/A X - - -
FA-14C FibreChannel Online ON ON N/A N/A X - - -
FA-3D FibreChannel Online ON ON N/A N/A - - - -
FA-4D FibreChannel Online ON ON N/A N/A - - - -
FA-7D FibreChannel Online ON ON N/A N/A - - - -
FA-8D FibreChannel Online ON ON N/A N/A - - - -
FA-9D FibreChannel Online ON ON N/A N/A - - - -
FA-10D FibreChannel Online ON ON N/A N/A - - - -
FA-13D FibreChannel Online ON ON N/A N/A - - - -
FA-14D FibreChannel Online ON ON N/A N/A - - - -
Legend for Connection Status:
(X) : Fibre Port is Connected to a Fibre Port (HBA, Switch or RF Director)
(-) : Fibre Port is Not Connected.
Thursday, September 23, 2010
How to check any failing disk on symm box
Symmetrix ID : 000190104xx4
No devices were found
Symmetrix ID : 000190104xx4
Timestamp of Status Data : 09/23/2010 18:48:
How to check any failing disk on symm box
Symmetrix ID : 000190104xx4
No devices were found
Symmetrix ID : 000190104xx4
Timestamp of Status Data : 09/23/2010 18:48:
Saturday, September 18, 2010
Recovery of VCMDB
a. Create empty VCMDB
#symmaskdb -sid symid -file file_bkp init
b. Recover VCMDB
# symmaskdb -sid symid -file file_bkp restore
c. Refresh the Symmetrix FA's with the new VCMDB
# symmask -sid symid refresh
Sunday, August 29, 2010
Netapp Snapmirror Setup Guide
Netapp Snapmirror Setup Guide
Snapmirrror needs a source and destination filer. (When source and destination are the same filer, the snapmirror happens on local filer itself. This is when you have to replicate volumes inside a filer. If you need DR capabilities of a volume inside a filer, you have to try syncmirror ).
Synchronous SnapMirror is a SnapMirror feature in which the data on one system is replicated on another system at, or near, the same time it is written to the first system. Synchronous SnapMirror synchronously replicates data between single or clustered storage systems situated at remote sites using either an IP or a Fibre Channel connection. Before Data ONTAP saves data to disk, it collects written data in NVRAM. Then, at a point in time called a consistency point, it sends the data to disk.
When the Synchronous SnapMirror feature is enabled, the source system forwards data to the destination system as it is written in NVRAM. Then, at the consistency point, the source system sends its data to disk and tells the destination system to also send its data to disk.
1) Enable Snapmirror on source and destination filer
source-filer> options snapmirror.enable
snapmirror.enable on
source-filer>
source-filer> options snapmirror.access
snapmirror.access legacy
source-filer>
2) Snapmirror Access
Make sure destination filer has snapmirror access to the source filer. The snapmirror filer's name or IP address should be in /etc/snapmirror.allow. Use wrfile to add entries to /etc/snapmirror.allow.
source-filer> rdfile /etc/snapmirror.allow
destination-filer
destination-filer2
source-filer>
3) Initializing a Snapmirror relation
Volume snapmirror : Create a destination volume on destination netapp filer, of same size as source volume or greater size. For volume snapmirror, the destination volume should be in restricted mode. For example, let us consider we are snapmirroring a 100G volume - we create the destination volume and make it restricted.
destination-filer> vol create demo_destination aggr01 100G
destination-filer> vol restrict demo_destination
Snapmirror is always destination filer driven. So the snapmirror initialize has to be done on destination filer. The below command starts the baseline transfer.
destination-filer> snapmirror initialize -S source-filer:demo_source destination-filer:demo_destination
Transfer started.
Monitor progress with 'snapmirror status' or the snapmirror log.
destination-filer>
Qtree Snapmirror : For qtree snapmirror, you should not create the destination qtree. The snapmirror command automatically creates the destination qtree. So just volume creation of required size is good enough.
destination-filer> snapmirror initialize -S source-filer:/vol/demo1/qtree destination-filer:/vol/demo1/qtree
Transfer started.
Monitor progress with 'snapmirror status' or the snapmirror log.
4) Monitoring the status : Snapmirror data transfer status can be monitored either from source or destination filer. Use "snapmirror status" to check the status.
destination-filer> snapmirror status
Snapmirror is on.
Source Destination State Lag Status
source-filer:demo_source destination-filer:demo_destination Uninitialized - Transferring (1690 MB done)
source-filer:/vol/demo1/qtree destination-filer:/vol/demo1/qtree Uninitialized - Transferring (32 MB done)
destination-filer>
5) Snapmirror schedule : This is the schedule used by the destination filer for updating the mirror. It informs the SnapMirror scheduler when transfers will be initiated. The schedule field can either contain the word sync to specify synchronous mirroring or a cron-style specification of when to update the mirror. The cronstyle schedule contains four space-separated fields.
If you want to sync the data on a scheduled frequency, you can set that in destination filer's /etc/snapmirror.conf . The time settings are similar to Unix cron. You can set a synchronous snapmirror schedule in /etc/snapmirror.conf by adding “sync” instead of the cron style frequency.
destination-filer> rdfile /etc/snapmirror.conf
source-filer:demo_source destination-filer:demo_destination - 0 * * * # This syncs every hour
source-filer:/vol/demo1/qtree destination-filer:/vol/demo1/qtree - 0 21 * * # This syncs every 9:00 pm
destination-filer>
6) Other Snapmirror commands
- To break snapmirror relation - do snapmirror quiesce and snapmirror break.
- To update snapmirror data - do snapmirror update
- To resync a broken relation - do snapmirror resync.
- To abort a relation - do snapmirror abort
Snapmirror do provide multipath support. More than one physical path between a source and a destination system might be desired for a mirror relationship. Multipath support allows SnapMirror traffic to be load balanced between these paths and provides for failover in the event of a network outage.
To read how to tune the performance & speed of the netapp snapmirror or snapvault replication transfers and adjust the transfer bandwidth , go to Tuning Snapmirror & Snapvault replication data transfer speed
source: http://unixfoo.blogspot.com/2009/01/netapp-snapmirror-setup-guide.html
Sunday, August 22, 2010
How to check symmetric environment status i.e powersupply
Symmetrix ID : 000000002705
Timestamp of Status Data : 08/23/2010 01:22:32
System Bay
Bay Name : SystemBay
Number of Fans : 3
Number of Power Supplies : 6
Number of Standby of Power Supplies : 6
Summary Status of Contained Modules
All Fans : Normal
All Power Supplies : Normal
All Standby Power Supplies : Normal
Drive Bays
Bay Name : Bay-1A
Number of Standby of Power Supplies : 8
Number of Drive Enclosures : 16
Summary Status of Contained Modules
All Enclosures : Normal
All Link Control Cards : Normal
All Power Supplies : Normal
All Standby Power Supplies : Normal
Bay Name : Bay-2A
Number of Standby of Power Supplies : 8
Number of Drive Enclosures : 16
Summary Status of Contained Modules
All Enclosures : Normal
All Link Control Cards : Normal
All Power Supplies : Normal
All Standby Power Supplies : Normal
Commons SYMCLI
symcfg
symcfg list- A brief description of the all connected Symmetrix boxes.symcfg -sid 1234 remove- Remove the array 1234 from symcfg list.symcfg -sid 1234 list -lockn all- List all the external locks held in Symmetrix array 1234.symcfg -sid 1234 -lockn 15 release -force- Release the lock 15 held on array 1234 .symcfg -sid 1234 list -v- Displays detailed information about the Symmetrix Array 1234.symcfg -sid 1234 -dir 4a -p 0 list -addr -avail- List the LUN information / availability of lun ids on port 4a0 in array 1234 .symcfg -sid 1234 list -rdfg all- List details about all the rdf groups in array.symcfg -sid 1234 list -rdfg 3- List details about rdf group 3 .symcfg -sid 1234 list -rdfg all -dynamic- List details about all the dynamic rdf groups in array .symcfg -sid 1234 list -rdfg all -static- List details about all the static rdf groups in array .symcfg -sid 1234 list -ra all- List all RA ports with details like rdfg number , remote array sid and online status.symcfg discover- Scans all the devices in hosts looking for new symmetrix devices and rebuilds the symmetrix configuration database .
symdev
symdev -sid 1234 list- List all devices in symmetrix 1234.symdev -sid 1234 list -noport- List the devices which are not mapped to any ports.symdev -sid 1234 list -noport -meta- List all unmapped meta devices .symdev -sid 1234 list -dynamic- List all devices whose dyn_rdf attribute set .symdev -sid 1234 list -hotspare- Checks whether hotspare invoked in the array .symdev -sid 1234 show ABC- show the detailed information about devioce ABC.symdev -sid 1234 write_disable ABC -SA all- Write disable the device ABC from through all directors.symdev -sid 1234 not_ready ABC -SA all- Not ready the device ABC from through all directors.
symmaskdb
symmaskdb -sid 1234 -dev ABC list assign- List the masking details of the dev ABC .symmaskdb -sid 1234 -wwn xxxxxxx list devs- List the devices masked to given wwn number .symmaskdb -sid 1234 -awwn hba_alias list devs- List the devices masked to given alias hba name .
symmask
symmask list hba- List HBA details of the host.symmask -sid 1234 -dir 4a -p 0 list logins- List out wwns logged through port 4a0 .symmask -sid 1234 list logins -wwn xxx- Check whether wwn xxx logged in to any of the FAs on array 1234.symmask -sid 1234 refresh- Refresh the VCM Data Base after a masking and unmasking operation.symmask -sid 1234 -wwn xxxx -dir 4a -p 0 add devs ABC,ABD- Mask the devices ABC and ABD to given wwn in 1234 arrray .symmask -sid 1234 -wwn xxxx -dir 4a -p 0 remove devs ABC,ABD- Unmask the devices ABC and ABD from given wwn in 1234 arrray .
symdg
symdg -sid 1234 list- List device groups which include the devices from array 1234.symdg create mydg -type rdf1- Create device group mydg of rdf1 type .symdg show mydg- Shows members/details of mydg.symdg rename mydg yourdg- Renames the mydg to yourdg.symdg delete mydg -force- Delete device group mydg.
symld
symld -g mydg -sid 1234 add dev ABC DEV006- Add the RDF device ABC to device group mydg as DEV006symld -g mydg remove DEV006- Remove DEV006 form device group mydg.
symrdf
symrdf -sid 1234 -rdfg 3 -type rdf1 -file rdf.txt -g mydg createpair -establish- Establish the SRDF relation between the devices given in the file rdf.txt from array 1234(R1) and remote box according to the rdf group . This command start sync between R1 and R2, and also add these devices after creating the device group mydg.symrdf -sid 1234 -rdfg 3 -file rdf.txt query- Query the Devices by using device pair file.symrdf -g mydg set mode acp_disk- Set synching mode to Adaptive Copy.symrdf -g mydg query- Query device group.symrdf -g mydg split- Split the srdf pair for devices given in mydg.symrdf -sid 1234 -rdfg 3 -file rdf.txt deletepair.txt -force- Delete the srdf pairing between R1/R2 and return them to stanadard.
symdisk
symdisk -sid 1234 list -hotspare- List Hotspares configured in the array.symdisk -sid 1234 list -by_diskgroup- Displays all the disks in array by disk groups.symdisk -sid 1234 list -diskg_group 1- Displays all the disks in disk group 1.
Saturday, August 14, 2010
How to rename wwn of the hosts to hostname/port#
symmask -sid xxxx -wwn
Saturday, July 24, 2010
Command to check disk presented to HBA
example of output
# cfgadm -al -o show_FCP_dev
Ap_Id Type Receptacle Occupant Condition
c7 fc-fabric connected configured unknown
c7::500308c001a1b8ab,0 array-ctrl connected configured unknown
c7::500308c001a1b8ab,1 tape connected configured unknown
c7::500308c001a1b8ab,2 tape connected configured unknown
c7::500308c001a1b8b2,0 array-ctrl connected configured unknown
c7::500308c001a1b8b2,1 tape connected configured unknown
c7::500308c001a1b8b2,2 tape connected configured unknown
c8 fc-fabric connected configured unknown
c8::5006048c52a65906,0 disk connected configured unknown
c8::5006048c52a65906,17 disk connected configured unknown
c8::5006048c52a65906,18 disk connected configured unknown
c8::5006048c52a65906,19 disk connected configured unknown
c8::5006048c52a65906,20 disk connected configured unknown
c8::5006048c52a65906,48 disk connected configured unknown
c8::5006048c52a65906,49 disk connected configured unknown
c9 fc-fabric connected configured unknown
c9::5006048c52a65909,0 disk connected configured unknown
c9::5006048c52a65909,17 disk connected configured unknown
c9::5006048c52a65909,18 disk connected configured unknown
c9::5006048c52a65909,19 disk connected configured unknown
c9::5006048c52a65909,20 disk connected configured unknown
c9::5006048c52a65909,48 disk connected configured unknown
c9::5006048c52a65909,49 disk connected configured unknown
c10
Wednesday, July 7, 2010
Scan for new disks
AIX# cfgmgr
AIX# fget_config -Av
Solaris:
Solaris# devfsadm
Solaris# cfgadm -a
Solaris# format (to view new devices)
Sun Solaris 9 Commands to Connect SAN Disks
There are always a bunch of strange commands to connect a server to SAN disks. In my case, I’m running Solaris 9, using QLogic Fibre Channel cards, and connecting to an IBM DS4300.
1) Connect the Solaris server SAN disks. After I made the connection, the GUI that allows me to zone the SAN recognized the QLogic connections, and I zoned the LUNs.
If you need more detailed instructions, here are some potentially useful posts: How to Zone a Brocade SAN Switch and How to Zone IBM DS4000 SAN Disks.
2) Scan your disks, and it should show up as a new disk when you run “format”.
Solaris# devfsadm
Solaris# format
My result: No new disks. Sigh.
3) Run a bunch of cryptic but useful diagnostic commands:
To see your HBA ports and whether you’re connected:
Solaris# luxadm -e port
Found path to 3 HBA ports
/devices/pci@8,700000/SUNW,qlc@2/fp@0,0:devctl CONNECTED
/devices/pci@8,700000/SUNW,qlc@2,1/fp@0,0:devctl CONNECTED
/devices/pci@8,600000/SUNW,qlc@4/fp@0,0:devctl CONNECTED
To see your disks:
Solaris# luxadm probe
To see your HBA ports (type fc-private, below) and their connected disks (type disk):
Solaris# cfgadm -al
Ap_Id Type Receptacle Occupant Condition
c8 fc-private connected configured unknown
c8::200800a0b8199b3b disk connected configured unknown
c9 fc-private connected configured unknown
c9::200900a0b8199b3b disk connected configured unknown
4) Force Fibre Channel SAN disk rescan, since everything looks connected and okay. Use your device path from “luxadm -e port” output.
Solaris# luxadm -e forcelip /devices/pci@8,700000/SUNW,qlc@2/fp@0,0:devctl
Solaris# luxadm -e forcelip /devices/pci@8,700000/SUNW,qlc@2,1/fp@0,0:devctl
Solaris# luxadm -e forcelip /devices/pci@8,600000/SUNW,qlc@4/fp@0,0:devctl
5) Rerun format command.
Solaris # format
AVAILABLE DISK SELECTIONS:
0. c1t0d0
/pci@8,600000/SUNW,qlc@4/fp@0,0/ssd@w500000e0107111e1,0
1. c1t1d0 t2
/pci@8,600000/SUNW,qlc@4/fp@0,0/ssd@w500000e01070d761,0
2. c7t600A0B801019B1B2002032A5489C60F3d0
/scsi_vhci/ssd@g600a0b801019b1b2002032a5489c60f3
source: http://technotes.twosmallcoins.com/?tag=devfsadm
Sunday, June 20, 2010
Examples of Symaccess CLI
Symmetrix ID : 111192601515
View
Group Name Count Count Type
-------------------------------- ----- ----- ---------
qqqS005_IG - - Initiator
qqqUXRAC01_IG - - Initiator
rrrXRAC02_IG - - Initiator
eeeXRAC01_US1SDUXRAC02_IG - - Initiator
eeREM001_IG - - Initiator
eeRAC35_IG - - Initiator
xxx15_8e1_9e1 - - Port
xxx515_5e0_6e0 - - Port
xxx515_5e1_6e1 - - Port
xx15_5f0_6f0 - - Port
xxx5_5f1_6f1 - - Port
xx5_5g0_6g0 - - Port
xxxQL001_SG - - Storage
xxxPACE02_SG - - Storage
xx035_SG - - Storage
xxxP001_SG - - Storage
xxRAC15_xxxRAC16_SG - - Storage
KOxxxC15_SG - - Storage
KOxxx16_SG - - Storage
#symacces -sid 515 list view
xxxS029_view xxxS029_IG bb_Symm_1515_3* Ufs029_SG
xxxS028_view UxxxS028_IG bb_Symm_1515_3* sff028_SG
xxxA1N1_view KxxxN1_IG bb_1515_8e0_9e0 KdsdA1N1_SG
xxxA1N2_view KOxx1N2_IG cc_1515_8e0_9e0 KdfA1N2_SG
KxxS088_view KxxxS088_IG ccc1515_8f0_9f0 dfUS088_SG
UxxxS021_view xxxUS021_IG ff1515_5e0_6* UdffS021_SG
xxxUS018_view vvvUS018_IG ffm_1515_5e0_6* ddf018_SG
xxxUS020_view bbbUS020_IG ffm_1515_5e0_6* d020_SG
xxxNEAM001_view UvvvAWNEAM001_IG Sddd5_8e0_7e0 dddNEAM001_SG
xxxS019_view UvvUS019_IG ddd1515_5e0_6* vvvUS019_SG
# symaccess -sid 515 list devinfo -ig S020_IG
Symmetrix ID : 0000000001515
Initiator Group Name : S020_IG
Last updated at : 11:09:04 AM on Fri Apr 23,2010
Host Initiators
{
WWN :1111001b32b47a66
WWN :1111001b32b44268
}
Sym Host Cap
Dev Dir:P Physical Device Name Lun Attr (MB) Masking View Name
----- ----- ----------------------- ---- ---- ------ ------------------------
0F94 05E:0 Not Visible 0 (M) 69060 S020_view
06E:0 Not Visible 0 (M) S020_view
0F9C 05E:0 Not Visible 1 (M) 69060 S020_view
06E:0 Not Visible 1 (M) S020_view
0FA4 05E:0 Not Visible 2 (M) 69060 S020_view
06E:0 Not Visible 2 (M) S020_view
0FAC 05E:0 Not Visible 3 (M) 69060 S020_view
06E:0 Not Visible 3 (M) S020_view
0FB4 05E:0 Not Visible 4 (M) 69060 S020_view
06E:0 Not Visible 4 (M) S020_view
0FBC 05E:0 Not Visible 5 (M) 69060 S020_view
06E:0 Not Visible 5 (M) S020_view
0FC4 05E:0 Not Visible 6 (M) 69060 S020_view
06E:0 Not Visible 6 (M) S020_view
------
Total Capacity 483420
# symaccess -sid 515 show S020_SG -type storage
Symmetrix ID : 11111101515
Storage Group Name : S020_SG
Last updated at : 11:09:04 AM on Fri Apr 23,2010
Devices : 0F94 0F9C 0FA4 0FAC 0FB4 0FBC 0FC4
Masking View Names
{
S020_view
}
# symaccess -sid 515 show S020_IG -type initiator
Symmetrix ID : 111112601515
Initiator Group Name : S020_IG
Last updated at : 11:09:04 AM on Fri Apr 23,2010
Host Initiators
{
WWN :1111001b32b47a66
WWN :1111001b32b44268
}
Masking View Names
{
S020_view
}
Parent Initiator Groups
{
None
}
# symaccess -sid 515 show xx15_5e0_6e0 -type port
Symmetrix ID : 12122601515
Port Group Name : xx1515_5e0_6e0
Last updated at : 07:28:52 AM on Fri Apr 23,2010
Director Identification
{
FA-5E:0
FA-6E:0
}
Masking View Names
{
S021_view
US018_view
S020_view
S019_view
}
# symaccess -sid 515 list assignment -dev 0F94
Symmetrix ID : xxxxx2601515
Device Identifier Type Dir:P
------ ---------------- ----- ----------------
0F94 111101b32b47a66 FIBRE FA-5E:0,FA-6E:0
1111001b32b44268 FIBRE FA-5E:0,FA-6E:0
How select select devices from particular a disk group
i.e
# symdev -sid 515 list -noport -disk_group 1
Symmetrix ID: 000192xxxxx
Device Name Directors Device
--------------------------- ------------- -------------------------------------
Cap
Sym Physical SA :P DA :IT Config Attribute Sts (MB)
--------------------------- ------------- -------------------------------------
0109 Not Visible ???:? 07D:C7 RAID-5 N/Grp'd (M) NR 115095
0123 Not Visible ???:? 10B:D9 RAID-5 N/Grp'd RW 14387
0124 Not Visible ???:? 10A:C9 RAID-5 N/Grp'd RW 14387
0127 Not Visible ???:? 09B:DE RAID-5 N/Grp'd (M) NR 115095
012F Not Visible ???:? 09B:D8 RAID-5 N/Grp'd (M) NR 115095
0137 Not Visible ???:? 09B:D6 RAID-5 N/Grp'd (M) NR 115095
013F Not Visible ???:? 09B:DA RAID-5 N/Grp'd (M) NR 115095
0147 Not Visible ???:? 07B:D4 RAID-5 N/Grp'd (M) NR 71934
0168 Not Visible ???:? 07A:DD RAID-5 N/Grp'd NR 14387
0177 Not Visible ???:? 07B:C5 RAID-5 N/Grp'd NR 14387
0179 Not Visible ???:? 07B:DA RAID-5 N/Grp'd NR 14387
0204 Not Visible ???:? 09A:D1 RDF2+R-5 N/Grp'd (M) WD 71934
0209 Not Visible ???:? 07D:DC RDF2+R-5 N/Grp'd (M) WD 71934
020E Not Visible ???:? 09A:D9 RDF2+R-5 N/Grp'd (M) WD 71934
0213 Not Visible ???:? 10B:DD RDF2+R-5 N/Grp'd (M) WD 71934
0218 Not Visible ???:? 09A:C6 RDF2+R-5 N/Grp'd (M) WD 71934
021D Not Visible ???:? 09B:CB RDF2+R-5 N/Grp'd (M) WD 71934
0222 Not Visible ???:? 10A:D8 RDF2+R-5 N/Grp'd (M) WD 71934
02A9 Not Visible ???:? 08D:D3 RAID-5 N/Grp'd (M) RW 71934
02CF Not Visible ???:? 07D:D8 RDF2+R-5 N/Grp'd (M) WD 28774
02D1 Not Visible ???:? 07D:C5 RAID-5 N/Grp'd (M) RW 28774
02D3 Not Visible ???:? 08D:D5 RDF2+R-5 N/Grp'd (M) WD 28774
02D5 Not Visible ???:? 08D:CA RDF2+R-5 N/Grp'd (M) WD 28774
02D7 Not Visible ???:? 10B:C2 RDF2+R-5 N/Grp'd (M) WD 28774
02D9 Not Visible ???:? 07D:C7 RDF2+R-5 N/Grp'd (M) WD 28774
02DB Not Visible ???:? 08D:D7 RDF2+R-5 N/Grp'd (M) WD 28774
02DD Not Visible ???:? 09B:D4 RDF2+R-5 N/Grp'd (M) WD 28774
02E1 Not Visible ???:? 10B:D3 RAID-5 N/Grp'd (M) RW 28774
02E3 Not Visible ???:? 09B:C3 RAID-5 N/Grp'd (M) RW 43161
02E6 Not Visible ???:? 09A:C0 RDF2+R-5 N/Grp'd (M) WD 43161
02E9 Not Visible ???:? 10B:D1 RDF2+R-5 N/Grp'd (M) WD 43161
02EC Not Visible ???:? 09A:D1 RDF2+R-5 N/Grp'd (M) WD 43161
02EF Not Visible ???:? 08D:CC RDF2+R-5 N/Grp'd (M) WD 43161
02F2 Not Visible ???:? 07C:CC RDF2+R-5 N/Grp'd (M) WD 43161
02F5 Not Visible ???:? 09B:C9 RAID-5 N/Grp'd (M) RW 43161
related:
symdisk -sid 123 list -by_diskgroup
symdisk -sid 123 list -disk_group
